import settings from '@/settings'
import request from '@/utils/request'
const systemPrefix = settings.systemPrefix

// 币种查询查询
  export function queryCurrency(param) {
    return request(`${systemPrefix}/im/dhc/zz/automake/zzmanage/currency_manager/CurrencyManagerController.do`, {
      method: 'post',
      data: param,
      requestType: 'form'
    });
  }

  export function getTabKeyRule(param) {
    return request(`${systemPrefix}/system/select/options/getTabKeyRule.do`, {
      method: 'post',
      data: param,
      requestType: 'form'
    });
  }
  export function CurrencyConversionController(param) {
    return request(`${systemPrefix}/im/dhc/zz/automake/zzmanage/currency_manager/CurrencyConversionController.do`, {
      method: 'post',
      data: param,
      requestType: 'form'
    });
  }
  export function validateRecord(param) {
    return request(`${systemPrefix}/financemanage/validateRecord.do`, {
      method: 'post',
      data: param,
      requestType: 'form'
    });
  }
  export function CurrencyModifyController(param) {
    return request(`${systemPrefix}/im/dhc/zz/automake/zzmanage/currency_manager/CurrencyModifyController.do`, {
      method: 'post',
      data: param,
      requestType: 'form',
      headers: {
        "X-Requested-With": "XMLHttpRequest"
      }
    });
  }
  export function CurrencyInsertController(param) {
    return request(`${systemPrefix}/im/dhc/zz/automake/zzmanage/currency_manager/CurrencyInsertController.do`, {
      method: 'post',
      data: param,
      requestType: 'form',
      headers: {
        "X-Requested-With": "XMLHttpRequest"
      }
    });
  }
  export function searchCurrency(param) {
    return request(`${systemPrefix}/im/dhc/currencymanager/searchCurrency.do`, {
      method: 'post',
      data: param,
      requestType: 'form',
      headers: {
        "X-Requested-With": "XMLHttpRequest"
      }
    });
  }
